DMT Exceptions
====================

Some DMT special exceptions, they refer to electrical engineering errors and less to implementation/coding errors.

Implemented Exceptions
-------------------------

.. automodule:: DMT.exceptions
    :members:
    :undoc-members:
    :show-inheritance:
